@@ -296,11 +296,16 @@ Frontend::ParseResult CscopeFrontend::parseStdout(QString& sToken,
 	case Func:
 		// Treat the token as the name of the function in this record
 		if (sToken.toInt()) {
-			// If it is number, then it is line number already
+			// In case of a global definition, there is no function name, and
+			// instead the line number is given immediately
 			m_state = LineText;
 			m_delim = Newline;
 		}
-		m_state = Line;
+		else {
+			// Not a number, it is the name of the function
+			m_state = Line;
+		}
+		
 		result = AcceptToken;
 		break;
 
