@@ -26,69 +26,11 @@
  ***************************************************************************/
 
 #include <qheader.h>
-#include <qtooltip.h>
 #include <klocale.h>
 #include "ctagslist.h"
 #include "kscopeconfig.h"
 #include "kscopepixmaps.h"
 
-/**
- * Tooltip class for the tag list.
- * For each item in the tag list the contents of the item
- * (the value of every column) is shown. This way if e.g.
- * the name of a function is not fully visible, a tooltip
- * frees the user from scrolling the list horizontaly.
- * @author Gabor Fekete
- */
-class CtagsToolTip : public QToolTip
-{
-public:
-	/**
-	 * Class constructor.
-	 * @param	pParent	Owner list view widget
-	 */
-	CtagsToolTip(QListView* pParent) : QToolTip(pParent->viewport()), 
-		m_pList(pParent) {}
-
-protected:
-	
-	/**
-	 * Displays a tool-tip according to the current location of the mouse
-	 * pointer.
-	 * @param	pt	The mouse pointer coordinates
-	 */
-	void maybeTip(const QPoint& pt) {
-		// Get the item at the given point
-		const QListViewItem* pItem = m_pList->itemAt(pt);
-		if (pItem == NULL)
-			return;
-			
-		// Get the bounding rectangle of the item
-		const QRect rcItem = m_pList->itemRect(pItem);
-		if (!rcItem.isValid())
-			return;
-			
-		// Get the header coordinates
-		const QRect rcHead = m_pList->header()->rect();
-		if (!rcHead.isValid())
-			return;
-			
-		// Calculate the tool-tip rectangle
-		QRect rcCell(rcHead.left(), rcItem.top(), rcItem.width(), 
-			rcItem.height());
-			
-		// Display the tool-tip
-		QString str;
-		str = QString("Type: <b>%1</b><br>Name: <b>%2</b><br>Line: <b>%3</b>").
-			arg(pItem->text(2)).arg(pItem->text(0)).arg(pItem->text(1));
-		tip(rcCell, str);
-	}
-
-private:
-	/** The owner list view widget. */
-	QListView* m_pList;
-};
-
 /**
  * Defines a special list item for the tag list.
  * This special definition allows the tag list to be sorted according to
@@ -207,10 +149,6 @@ CtagsList::CtagsList(QWidget* pParent, const char* szName) :
 	m_pList->addColumn(i18n("Type"));
 	m_pList->setColumnAlignment(1, Qt::AlignRight);
 
-	// Set up the tooltip generator
-	QToolTip::remove(m_pList);
-	m_pToolTip = new CtagsToolTip(m_pList);
-
 	// Set colours and font
 	applyPrefs();
 }
@@ -220,7 +158,6 @@ CtagsList::CtagsList(QWidget* pParent, const char* szName) :
  */
 CtagsList::~CtagsList()
 {
-	delete m_pToolTip;
 }
 
 /**
@@ -336,6 +273,19 @@ void CtagsList::processItemSelected(QListViewItem* pItem)
 	emit lineRequested(sLine.toUInt());
 }
 
+/**
+ * Constructs a tool-tip for the given item.
+ * @param	pItem	The item for which a tip is required
+ * @param	sTip	The constructed tip string (on return)
+ * @return	Always true
+ */
+bool CtagsList::getTip(QListViewItem* pItem, QString& sTip)
+{
+	sTip = QString("Type: <b>%1</b><br>Name: <b>%2</b><br>Line: <b>%3</b>").
+		arg(pItem->text(2)).arg(pItem->text(0)).arg(pItem->text(1));
+	return true;
+}
+
 /**
  * Sets the list's colours and font, according the user's preferences.
  */
