@@ -170,6 +170,18 @@ void FileList::setRoot(const QString& sRoot)
 	}
 }
 
+/**
+ * Constructs a tool-tip for the given item.
+ * @param	pItem	The item for which a tip is required
+ * @param	sTip	The constructed tip string (on return)
+ * @return	Always true
+ */
+bool FileList::getTip(QListViewItem* pItem, QString& sTip)
+{
+	sTip = pItem->text(2);
+	return true;
+}
+
 /**
  * Sets the keyboad focus to the search box.
  * This slot is connected to a keyboard shortcuts for quick access to the
