@@ -1,18 +1,28 @@
 /***************************************************************************
-                          projectmanager.cpp  -  description
-                             -------------------
-    begin                : Sat May 10 2003
-    copyright            : (C) 2003 by Elad Lahav
-    email                : elad_lahav@users.sf.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
+ *
+ * Copyright (C) 2005 Elad Lahav (elad_lahav@users.sourceforge.net)
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * 
+ * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+ * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
+ * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
+ * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
+ * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
+ * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+ * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
+ * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ *
  ***************************************************************************/
 
 #include <unistd.h>
@@ -418,9 +428,85 @@ void ProjectManager::setOptions(const Options& opt)
 /**
  * Reads the paths of the files that were open when the project was closed,
  * and fills a list used to restore the previous session.
- * @param	slOpenFiles	The list to fill
+ * The list is composed of the file paths and the current position of the
+ * cursor inside each file (@see FileLocation).
+ * @param	list	The list to fill
  */
-void ProjectManager::getOpenFiles(QStringList& slOpenFiles) const
+void ProjectManager::getOpenFiles(OpenFileList& list) const
+{
+	QStringList slEntry;
+	QStringList::Iterator itr;
+	QString sPath;
+	uint nLine, nCol;
+	
+	// Must have an open persistent project
+	if (!m_bOpen || m_bTempProj)
+		return;
+
+	// Read the file paths
+	m_pConf->setGroup("Session");
+	slEntry = m_pConf->readListEntry("OpenFiles");
+	
+	// Transform the entry into a list of file locations
+	for (itr = slEntry.begin(); itr != slEntry.end(); ++itr) {
+		sPath = (*itr).section(':', 0, 0);
+		nLine = (*itr).section(':', 1, 1).toUInt();
+		nCol = (*itr).section(':', 2, 2).toUInt();
+		list.append(new FileLocation(sPath, nLine, nCol));
+	}
+}
+
+/**
+ * Writes a list of open files to the project's configuration file.
+ * The list is composed of the file paths and the current position of the
+ * cursor inside each file.
+ * The method is called before a project is closed, so these file paths can
+ * be read when the project is restored.
+ * @param	list	The list of file paths to write
+ */
+void ProjectManager::setOpenFiles(OpenFileList& list)
+{
+	FileLocation* pLoc;
+	QString sLoc;
+	QStringList slEntry;
+	
+	// Must have an open persistent project
+	if (!m_bOpen || m_bTempProj)
+		return;
+
+	// Turn the object list into a string list, so that it can be written in
+	// the configuration file
+	for (pLoc = list.first(); pLoc != NULL; pLoc = list.next()) {
+		sLoc = "";
+		QTextOStream(&sLoc) << pLoc->m_sPath << ":" << pLoc->m_nLine << ":" 
+			<< pLoc->m_nCol;
+		slEntry.append(sLoc);
+	}
+
+	// Write the file paths
+	m_pConf->setGroup("Session");
+	m_pConf->writeEntry("OpenFiles", slEntry);
+}
+
+/**
+ * @return	The full path of the file that was active when the session was
+ *			closed
+ */
+QString ProjectManager::getLastOpenFile() const
+{
+	// Must have an open persistent project
+	if (!m_bOpen || m_bTempProj)
+		return "";
+
+	// Read the file paths
+	m_pConf->setGroup("Session");
+	return m_pConf->readEntry("LastOpenFile");
+}
+
+/**
+ * @param	sPath	The full path of the currently active file
+ */
+void ProjectManager::setLastOpenFile(const QString& sPath)
 {
 	// Must have an open persistent project
 	if (!m_bOpen || m_bTempProj)
@@ -428,24 +514,7 @@ void ProjectManager::getOpenFiles(QStringList& slOpenFiles) const
 
 	// Read the file paths
 	m_pConf->setGroup("Session");
-	slOpenFiles = m_pConf->readListEntry("OpenFiles");
-}
-
-/**
- * Writes a list of open files to the project's configuration file.
- * The method is called before a project is closed, so these file paths can
- * be read when the project is restored.
- * @param	slOpenFiles	The list of file paths to write
- */
-void ProjectManager::setOpenFiles(QStringList& slOpenFiles)
-{
-	// Must have an open persistent project
-	if (!m_bOpen || m_bTempProj)
-		return;
-
-	// Write the file paths
-	m_pConf->setGroup("Session");
-	m_pConf->writeEntry("OpenFiles", slOpenFiles);
+	m_pConf->writeEntry("LastOpenFile", sPath);
 }
 
 /**
@@ -671,3 +740,5 @@ void ProjectManager::writeOptions(KConfig* pConf, const Options& opt)
 	pConf->writeEntry("Delay", opt.nACDelay);
 	pConf->writeEntry("MaxEntries", opt.nACMaxEntries);
 }
+
+#include "projectmanager.moc"
