@@ -54,74 +54,57 @@ public slots:
 	
 signals:
 	/** 
-	 * Indicates the "View Source" menu item has been selected. 
+	 * Indicates that the "View Source" menu item was selected. 
 	 * @param	pItem	The item for which the menu was displayed
 	 */
 	void viewSource(QListViewItem* pItem);
 	 
+	/**
+	 * Indicates that the "Find Definition" menu item was selected.
+	 * @param	sFunc	The function to look for
+	 */
+	void findDef(const QString& sFunc);
+	
 	/** 
-	 * Indicates a "Copy [Field]" menu item has been selected. 
+	 * Indicates that the "Copy [Column]" menu item was selected. 
 	 * @param	pItem	The item for which the menu was displayed
 	 * @param	nCol	The requested column
 	 */
 	void copy(QListViewItem* pItem, int nCol);
 	
 	/**
-	 * Emitted after the user selects search criteria in the "Search Query
-	 * Results" dialogue.
-	 * @param	pItem	The item for which the menu was displayed
-	 * @param	re		The regular expression to search
+	 * Indicates that the "Filter..." menu item was selected.
 	 * @param	nCol	The column in which to search
 	 */
-	void search(QListViewItem* pItem, const QRegExp& re, int nCol);
+	void filter(int nCol);
 	
 	/**
-	 * Indicates the "Show All" menu item has been selected.
-	 * @param	pItem	The item for which the menu was displayed
+	 * Indicates that the "Show All" menu item was selected.
 	 */
-	void showAll(QListViewItem*);
+	void showAll();
 	
 	/** 
-	 * Indicates the "Remove Item" menu item has been selected. 
+	 * Indicates that the "Remove Item" menu item was selected. 
 	 * @param	pItem	The item for which the menu was displayed
 	 */
 	void remove(QListViewItem* pItem);
 	
 private:
-	/** The "View Source" menu item identifier. */
-	int m_nViewSourceId;
-	
-	/** The "Copy File" menu item identifier. */
-	int m_nCopyFileId;
-	
-	/** The "Copy Function" menu item identifier. */
-	int m_nCopyFuncId;
-	
-	/** The "Copy Line" menu item identifier. */
-	int m_nCopyLineId;
-	
-	/** The "Copy Text" menu item identifier. */
-	int m_nCopyTextId;
-	
-	/** The "Search..." menu item identifier. */
-	int m_nSearchId;
-	
-	/** The "Show All" menu item identifier. */
-	int m_nShowAllId;
-	
-	/** The "Remove Item" menu item identifier. */
-	int m_nRemItemId;
-	
+	/** Menu item IDs. */
+	enum { ViewSource, FindDef, Copy, Filter, ShowAll, Remove };
+		
 	/** The item for which the popup menu is provided (cannot be NULL). */
 	QListViewItem* m_pItem;
 	
-	/** The query field for which the query was invoked. */
-	int m_nField;
-		
-	void showSearchDlg();
+	/** The list column for which the query was invoked. */
+	int m_nCol;
 	
 private slots:
-	void slotActivated(int);
+	void slotViewSource();
+	void slotFindDef();
+	void slotCopy();
+	void slotFilter();
+	void slotRemove();
 };
 
 #endif
