@@ -25,6 +25,7 @@
  *
  ***************************************************************************/
 
+#include <qheader.h>
 #include "searchlist.h"
 
 /**
@@ -46,6 +47,54 @@ void SearchLineEdit::keyPressEvent(QKeyEvent* pKey)
 		break;
 	}
 }
+	
+/**
+ * Class constructor.
+ * @param	pParent	Owner list view widget
+ */
+ListToolTip::ListToolTip(SearchList* pParent) : 
+	QToolTip(pParent->getList()->viewport()), 
+	m_pList(pParent)
+{
+}
+
+/**
+ * Displays a tool-tip according to the current location of the mouse
+ * pointer.
+ * @param	pt	The mouse pointer coordinates
+ */
+void ListToolTip::maybeTip(const QPoint& pt)
+{
+	QString str;
+	QListView* pList;
+	QListViewItem* pItem;
+	
+	// Get the item at the given point
+	pList = m_pList->getList();
+	pItem = pList->itemAt(pt);
+	if (pItem == NULL)
+		return;
+
+	// Get the tip string for this item
+	if (!m_pList->getTip(pItem, str))
+		return;
+
+	// Get the bounding rectangle of the item
+	const QRect rcItem = pList->itemRect(pItem);
+	if (!rcItem.isValid())
+		return;
+
+	// Get the header coordinates
+	const QRect rcHead = pList->header()->rect();
+	if (!rcHead.isValid())
+		return;
+
+	// Calculate the tool-tip rectangle
+	QRect rcCell(rcHead.left(), rcItem.top(), rcItem.width(), rcItem.height());
+
+	// Display the tool-tip
+	tip(rcCell, str);
+}
 
 /**
  * Class constructor.
@@ -57,9 +106,14 @@ SearchList::SearchList(int nSearchCol, QWidget* pParent, const char* szName) :
 	QVBox(pParent, szName),
 	m_nSearchCol(nSearchCol)
 {
+	// Create the child widgets
 	m_pEdit = new SearchLineEdit(this);
 	m_pList = new QListView(this);
-
+	
+	// Set up the tooltip generator
+	QToolTip::remove(m_pList);
+	m_pToolTip = new ListToolTip(this);
+	
 	connect(m_pEdit, SIGNAL(textChanged(const QString&)), this,
 		SLOT(slotFindItem(const QString&)));
 	connect(m_pList, SIGNAL(doubleClicked(QListViewItem*)), this,
@@ -77,6 +131,7 @@ SearchList::SearchList(int nSearchCol, QWidget* pParent, const char* szName) :
  */
 SearchList::~SearchList()
 {
+	delete m_pToolTip;
 }
 
 /**
