@@ -32,6 +32,9 @@
 #include <qvbox.h>
 #include <qlineedit.h>
 #include <qlistview.h>
+#include <qtooltip.h>
+
+class SearchList;
 
 /**
  * Defines a line text edit for searchable list view.
@@ -39,19 +42,40 @@
  * Supported key events (up and down) are emitted as signals
  * @author Albert Yosher
  */
-
 class SearchLineEdit : public QLineEdit
 {
    Q_OBJECT
 public:
 	SearchLineEdit(QWidget* pParent) : QLineEdit(pParent) {};
 	~SearchLineEdit() {};
+	
 signals:
 	void keyPressed(QKeyEvent* e);
+	
 private:
 	virtual void keyPressEvent(QKeyEvent*);
 };
 
+/**
+ * A tool-tip class for the search list.
+ * Enables sub-classes of the list to provide a customised tool-tip for each 
+ * list item.
+ * @author Gabor Fekete
+ */
+class ListToolTip : public QToolTip
+{
+public:
+	ListToolTip(SearchList* pParent);
+
+protected:
+	virtual void maybeTip(const QPoint& pt);
+	
+private:
+	/** The owner widget. */
+	SearchList* m_pList;
+};
+
+
 /**
  * Defines a searchable list view.
  * The widget is composed of a list view, and an edit box used to enter
@@ -59,7 +83,6 @@ private:
  * set to point to the first item that matches the new text.
  * @author Elad Lahav
  */
-
 class SearchList : public QVBox
 {
    Q_OBJECT
@@ -72,6 +95,14 @@ public:
 	 * @return	A pointer to the list part of the widget.
 	 */
 	QListView* getList() { return m_pList; }
+	
+	/**
+	 * Constructs a tool-tip for the given item.
+	 * @param	pItem	The item for which a tip is required
+	 * @param	sTip	The constructed tip string (on return)
+	 * @return	True to display the tip, false otherwise
+	 */
+	virtual bool getTip(QListViewItem* pItem, QString& sTip) = 0;
 
 protected:
 	/** The search edit-box. */
@@ -97,6 +128,9 @@ private:
 	/** Specifies the search column, i.e., the list column whose strings are
 		compared with the text in the search edit-box. */
 	int m_nSearchCol;
+	
+	/** A tool-tip for the list entries. */
+	ListToolTip* m_pToolTip;
 };
 
 #endif
